#############################################################################
# Author:                                                                   #
# ------                                                                    #
#  Anton Kokalj                                  Email: Tone.Kokalj@ijs.si  #
#  Department of Physical and Organic Chemistry  Phone: x 386 1 477 3523    #
#  Jozef Stefan Institute                          Fax: x 386 1 477 3811    #
#  Jamova 39, SI-1000 Ljubljana                                             #
#  SLOVENIA                                                                 #
#                                                                           #
# Source: $XCRYSDEN_TOPDIR/Tcl/wnKPath.tcl                                       
# ------                                                                    #
# Copyright (c) 1996-2003 by Anton Kokalj                                   #
#############################################################################

proc wnKPath dir {
    global Bz BzOK prop system geng periodic xcMisc
    # now struct file should be read and then BZ toplevel displayed with
    # XCrySDen's k-Path Selection: directory

    XCRYSDEN_Logo $dir

    if [winfo exists .title] { 
	destroy .title 
    }


    ##########################################
    # in WIEN97 there it is always 3D system #
    ##########################################
    set periodic(dim) 3
    set species crystal

    cd $system(SCRDIR)

    set BzOK(wien_kpath) 1    
    set BzOK(wien_dir) [file tail $dir]

    #
    # read the struct file and produce xc_struc.$$
    #
    set filehead $dir/[file tail $dir]
    xcDebug "executing: $system(FORDIR)/str2xcr $filehead, PWD=[pwd]"
    if [catch {exec $system(FORDIR)/str2xcr $filehead}] {
	tk_dialog [WidgetName] ERROR \
		"ERROR while executing \"str2xcr\" program" \
		error 0 OK
    }
    # now copy $filehead.xcr to $system(SCRDIR)/xc_str2xcr.$$
    exec mv ${filehead}.xcr $system(SCRDIR)/xc_str2xcr.$system(PID)

    #
    # WIEN97 struct file is in BOHRs, thatwhy xc_str2xcr.$$ is in BOHRs
    #
    set geng(M3_ARGUMENT) [GetGengM3Arg BOHR 95]
    xcAppendState wien
    set periodic(igroup) 1
    xcDebug "Going to GenGeom"
    GenGeom $geng(M1_PRIM) $geng(M2_CELL) $geng(M3_ARGUMENT) \
	    $periodic(igroup) \
	    1 1 1 $system(SCRDIR)/xc_struc.$system(PID)
    xcDebug "Going to xc_readXSF"
    ################################################
    xc_readXSF $system(SCRDIR)/xc_struc.$system(PID)
    ################################################
    
    xcDebug "Going to Bz_MakeToplevel"
    set BzOK(done) 0
    Bz_MakeToplevel    

    xcDebug "BzOK(done) == $BzOK(done)"
    if !$BzOK(done) {
	# cancel button was pressed; EXIT
	exit_pr -silent
	exit
    }
    
    # OK button was pressed; prepare k_list-file
    # band structure script looks like:
    # BAND
    #a-b-c-d-
    #3 8 200 1 100 1 0
    #0 0 0    4 4 0
    #4 4 0    4 2 -2
    #4 2 -2    5 3 0    
    set script [split $prop(c95_BAND_script) \n]
    set labels [split [lindex $script 1] -]
    set idv    $BzOK(iss)
    set kp     [expr $prop(NLINE) + 1]
    set nk     $BzOK(nK)
    set emin   $BzOK(Emin)
    set emax   $BzOK(Emax)
    for {set i 3} {$i < [expr 2 + $prop(NLINE)]} {incr i} {
	set line [lindex $script $i]
	set ii [expr $i - 3]
	set coor(x,$ii) [lindex $line 0]
	set coor(y,$ii) [lindex $line 1] 
	set coor(z,$ii) [lindex $line 2]
    }
    set line [lindex $script $i]
    set ii [expr $i - 3]
    set coor(x,$ii) [lindex $line 0]
    set coor(y,$ii) [lindex $line 1] 
    set coor(z,$ii) [lindex $line 2]
    incr ii
    set coor(x,$ii) [lindex $line 3]
    set coor(y,$ii) [lindex $line 4] 
    set coor(z,$ii) [lindex $line 5]
    
    # now we are ready to construct k_list file
    set    k_list "$kp $nk $idv $emin $emax\n"
    append k_list "$Bz(rendered)\n"
    set unk 0
    for {set i 0} {$i <= $ii} {incr i} {
	set l [lindex $labels $i]
	if { $l == {} } { 
	    set l X$unk 
	    incr unk
	}
	set l [format "'%-10s'" $l]
	append k_list "$coor(x,$i) $coor(y,$i) $coor(z,$i)     $l\n"
    }

    xcDebug "k_list-file:"
    xcDebug "------------"
    xcDebug $k_list

    WriteFile $system(SCRDIR)/xc_klist.$system(PID) $k_list w
    set filetypes {
	{{WIEN97 K-List File} {.klist} }
	{{All Files}          *        }
    }
    set sfile [tk_getSaveFile -initialdir $system(PWD) \
	    -title "Save WIEN97 K-List File" \
	    -defaultextension .klist \
	    -filetypes $filetypes]    
    
    # maybe Cancel button was pressed
    if { $sfile == {} } { exit_pr -silent; exit }

    xcDebug "exec $system(FORDIR)/kPath  \
	    $system(SCRDIR)/xc_struc.$system(PID) \
	    $system(SCRDIR)/xc_klist.$system(PID)"
    if [catch {exec $system(FORDIR)/kPath  \
	    $system(SCRDIR)/xc_struc.$system(PID) \
	    $system(SCRDIR)/xc_klist.$system(PID) > \
	    $sfile}] {
	tk_dialog [WidgetName] ERROR \
		"ERROR while executing \"kPath\" program" \
		error 0 OK
    }
    
    exit_pr -silent
    exit
}
